==> p5-Alien-wxWidgets-0.67p0.tgz: libdata/perl5/site_perl/powerpc-openbsd/Alien/wxWidgets/Config/gtk2_gcc.pm <==
package Alien::wxWidgets::Config::gtk2_gcc;

use strict;

our %VALUES;

{
    no strict 'vars';
    %VALUES = %{
$VAR1 = {
          'defines' => '-D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_IODBC_ -D__WXGTK__ ',
          'include_path' => '-I/usr/local/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/local/include -I/usr/X11R6/include ',
          '_libraries' => {
                            'gizmos' => {
                                          'link' => '-lwx_gtk2_gizmos',
                                          'dll' => 'libwx_gtk2_gizmos.so.3.0'
                                        },
                            'adv' => {
                                       'link' => '-lwx_gtk2_adv',
                                       'dll' => 'libwx_gtk2_adv.so.3.0'
                                     },
                            'xml' => {
                                       'link' => '-lwx_base_xml',
                                       'dll' => 'libwx_base_xml.so.3.0'
                                     },
                            'net' => {
                                       'dll' => 'libwx_base_net.so.3.0',
                                       'link' => '-lwx_base_net'
                                     },
                            'xrc' => {
                                       'link' => '-lwx_gtk2_xrc',
                                       'dll' => 'libwx_gtk2_xrc.so.3.0'
                                     },
                            'media' => {
                                         'link' => '-lwx_gtk2_media',
                                         'dll' => 'libwx_gtk2_media.so.3.0'
                                       },
                            'base' => {
                                        'link' => '-lwx_base',
                                        'dll' => 'libwx_base.so.3.0'
                                      },
                            'html' => {
                                        'link' => '-lwx_gtk2_html',
                                        'dll' => 'libwx_gtk2_html.so.3.0'
                                      },
                            'richtext' => {
                                            'dll' => 'libwx_gtk2_richtext.so.3.0',
                                            'link' => '-lwx_gtk2_richtext'
                                          },
                            'gl' => {
                                      'link' => '-lwx_gtk2_gl',
                                      'dll' => 'libwx_gtk2_gl.so.3.0'
                                    },
                            'fl' => {
                                      'dll' => 'libwx_gtk2_fl.so.3.0',
                                      'link' => '-lwx_gtk2_fl'
                                    },
                            'stc' => {
                                       'link' => '-lwx_gtk2_stc',
                                       'dll' => 'libwx_gtk2_stc.so.3.0'
                                     },
                            'core' => {
                                        'link' => '-lwx_gtk2_core',
                                        'dll' => 'libwx_gtk2_core.so.3.0'
                                      },
                            'aui' => {
                                       'dll' => 'libwx_gtk2_aui.so.3.0',
                                       'link' => '-lwx_gtk2_aui'
                                     },
                            'qa' => {
                                      'link' => '-lwx_gtk2_qa',
                                      'dll' => 'libwx_gtk2_qa.so.3.0'
                                    }
                          },
          'alien_package' => 'Alien::wxWidgets::Config::gtk2_gcc',
          'prefix' => '/usr/local',
          'link_libraries' => ' -L/usr/local/lib -pthread -L/usr/local/lib -L/usr/X11R6/lib',
          'compiler' => 'c++',
          'c_flags' => '-pthread ',
          'version' => '2.008012',
          'alien_base' => 'gtk2_gcc',
          'config' => {
                        'compiler_kind' => 'gcc',
                        'unicode' => 0,
                        'mslu' => 0,
                        'compiler_version' => '3.4',
                        'debug' => 0,
                        'build' => 'multi',
                        'toolkit' => 'gtk2'
                      },
          'link_flags' => '',
          'linker' => 'c++ -shared -fPIC  '
        };
    };
}

my $key = substr __PACKAGE__, 1 + rindex __PACKAGE__, ':';

sub values { %VALUES, key => $key }

sub config {
   +{ %{$VALUES{config}},
      package       => __PACKAGE__,
      key           => $key,
      version       => $VALUES{version},
      }
}

1;

==> p5-Alien-wxWidgets-0.69.tgz: libdata/perl5/site_perl/powerpc-openbsd/Alien/wxWidgets/Config/gtk2_gcc.pm <==
package Alien::wxWidgets::Config::gtk2_gcc;

use strict;

our %VALUES;

{
    no strict 'vars';
    %VALUES = %{
$VAR1 = {
          '_libraries' => {
                            'adv' => {
                                       'dll' => 'libwx_gtk2_adv.so.3.0',
                                       'link' => '-lwx_gtk2_adv'
                                     },
                            'aui' => {
                                       'dll' => 'libwx_gtk2_aui.so.3.0',
                                       'link' => '-lwx_gtk2_aui'
                                     },
                            'base' => {
                                        'dll' => 'libwx_base.so.3.0',
                                        'link' => '-lwx_base'
                                      },
                            'core' => {
                                        'dll' => 'libwx_gtk2_core.so.3.0',
                                        'link' => '-lwx_gtk2_core'
                                      },
                            'fl' => {
                                      'dll' => 'libwx_gtk2_fl.so.3.0',
                                      'link' => '-lwx_gtk2_fl'
                                    },
                            'gizmos' => {
                                          'dll' => 'libwx_gtk2_gizmos.so.3.0',
                                          'link' => '-lwx_gtk2_gizmos'
                                        },
                            'gl' => {
                                      'dll' => 'libwx_gtk2_gl.so.3.0',
                                      'link' => '-lwx_gtk2_gl'
                                    },
                            'html' => {
                                        'dll' => 'libwx_gtk2_html.so.3.0',
                                        'link' => '-lwx_gtk2_html'
                                      },
                            'media' => {
                                         'dll' => 'libwx_gtk2_media.so.3.0',
                                         'link' => '-lwx_gtk2_media'
                                       },
                            'net' => {
                                       'dll' => 'libwx_base_net.so.3.0',
                                       'link' => '-lwx_base_net'
                                     },
                            'qa' => {
                                      'dll' => 'libwx_gtk2_qa.so.3.0',
                                      'link' => '-lwx_gtk2_qa'
                                    },
                            'richtext' => {
                                            'dll' => 'libwx_gtk2_richtext.so.3.0',
                                            'link' => '-lwx_gtk2_richtext'
                                          },
                            'stc' => {
                                       'dll' => 'libwx_gtk2_stc.so.3.0',
                                       'link' => '-lwx_gtk2_stc'
                                     },
                            'xml' => {
                                       'dll' => 'libwx_base_xml.so.3.0',
                                       'link' => '-lwx_base_xml'
                                     },
                            'xrc' => {
                                       'dll' => 'libwx_gtk2_xrc.so.3.0',
                                       'link' => '-lwx_gtk2_xrc'
                                     }
                          },
          'alien_base' => 'gtk2_gcc',
          'alien_package' => 'Alien::wxWidgets::Config::gtk2_gcc',
          'c_flags' => '-pthread ',
          'compiler' => 'c++',
          'config' => {
                        'build' => 'multi',
                        'compiler_kind' => 'gcc',
                        'compiler_version' => '3.4',
                        'debug' => 0,
                        'mslu' => 0,
                        'toolkit' => 'gtk2',
                        'unicode' => 0
                      },
          'defines' => '-D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_IODBC_ -D__WXGTK__ ',
          'include_path' => '-I/usr/local/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/local/include -I/usr/X11R6/include ',
          'link_flags' => '',
          'link_libraries' => ' -L/usr/local/lib -pthread -L/usr/local/lib -L/usr/X11R6/lib',
          'linker' => 'c++ -shared -fPIC  ',
          'prefix' => '/usr/local',
          'version' => '2.008012'
        };
    };
}

my $key = substr __PACKAGE__, 1 + rindex __PACKAGE__, ':';

sub values { %VALUES, key => $key }

sub config {
   +{ %{$VALUES{config}},
      package       => __PACKAGE__,
      key           => $key,
      version       => $VALUES{version},
      }
}

1;
